<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="100px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="人工编号" prop="handymanNo">
            <el-input v-model="dataForm.handymanNo" placeholder=""></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="人工名称" prop="handymanName">
            <el-input v-model="dataForm.handymanName" placeholder=""></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="工作站" prop="workstationName">
            <el-input
              v-model="dataForm.workstationName"
              placeholder=""
              readonly
            >
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openWorkstationDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="工时系数" prop="standardHourWage">
            <el-input
              v-model="dataForm.standardHourWage"
              placeholder=""
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="单位" prop="unit">
            <el-select
              v-model="dataForm.unit"
              placeholder=""
              filterable
              clearable
              style="width: 100%"
            >
              <el-option
                v-for="item in unitOptions"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="备注" prop="comment">
            <el-input v-model="dataForm.comment" placeholder=""></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件族" prop="partFamilyNo">
            <el-input v-model="dataForm.partFamilyNo" placeholder="" readonly>
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openPartFamilyDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="工作量类型" prop="loadType">
            <el-select
              v-model="dataForm.loadType"
              placeholder=""
              filterable
              clearable
              style="width: 100%"
            >
              <el-option
                v-for="item in loadTypeOptions"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
    <part-family
      :currshowlist.sync="showPartFamily"
      ref="PartFamily"
      @listenToPartFamilyEvent="selectPartFamily"
    />
    <workstation-dialog
      :currshowlist.sync="showWorkstationList"
      ref="workstationRef"
      @listenToWorkStationEvent="selectWorkstation"
    />
  </el-dialog>
</template>

<script>
import { getObj, addObj, putObj } from '@/api/product/handymantype'
import { remote } from '@/api/admin/dict'
import { validateSixDecimalNotNull, validateSixDecimal } from '@/util/validate'
import PartFamily from '../../common/partfamily'
import workstationDialog from '@/views/common/workstation'

export default {
  components: { PartFamily, workstationDialog },
  data() {
    return {
      showPartFamily: false,
      wageTypeOptions: [],
      loadTypeOptions: [],
      unitOptions: [],
      visible: false,
      dataForm: {
        id: 0,
        handymanNo: '',
        handymanName: '',
        conversionCoefficient: '',
        standardHourWage: '',
        discountFactor: '',
        comment: '',
        wageType: '',
        loadType: '',
        unit: '',
        partFamilyNo: '',
        partFamilyId: '',
        workstationName: null,
        workstationId: null
      },
      dataRule: {
        handymanName: [
          { required: true, message: '人工名称不能为空', trigger: 'blur' }
        ],
        conversionCoefficient: [
          { required: true, message: '转换系数不能为空', trigger: 'blur' },
          { validator: validateSixDecimalNotNull, trigger: 'blur' }
        ],
        standardHourWage: [
          { required: true, message: '工时系数不能为空', trigger: 'blur' },
          { validator: validateSixDecimalNotNull, trigger: 'blur' }
        ]
      },
      isSubmit: false,
      showWorkstationList: false
    }
  },
  created() {
    this.initOptions()
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        } else {
          this.dataForm.conversionCoefficient = 1
        }
      })
    },
    // 打开工作站列表弹框
    openWorkstationDialog() {
      this.showWorkstationList = true
    },
    openPartFamilyDialog() {
      this.showPartFamily = true
    },
    selectWorkstation(row) {
      this.dataForm.workstationId = row.id
      this.dataForm.workstationName = row.name
    },
    selectPartFamily(param) {
      if (param) {
        this.dataForm.partFamilyNo = param.partFamilyNo
        this.dataForm.partFamilyId = param.id
        this.$refs.dataForm.validateField('partFamilyNo', (valid) => {})
      }
    },

    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    },
    /**
     * 获取字典显示名称并缓存
     */
    initOptions() {
      remote('wage_type').then((response) => {
        if (response.data.code === 0) {
          this.wageTypeOptions = response.data.data
        }
      })
      remote('load_type').then((response) => {
        if (response.data.code === 0) {
          this.loadTypeOptions = response.data.data
        }
      })
      remote('workload_unit').then((response) => {
        if (response.data.code === 0) {
          this.unitOptions = response.data.data
        }
      })
    }
  }
}
</script>
